from app.models import ContactPerson, Address, Dewar, Proposal, Shipment, Puck, Sample
from datetime import datetime
import random

contacts = [
    ContactPerson(id=1, firstname="Frodo", lastname="Baggins", phone_number="123-456-7890",
                  email="frodo.baggins@lotr.com"),
    ContactPerson(id=2, firstname="Samwise", lastname="Gamgee", phone_number="987-654-3210",
                  email="samwise.gamgee@lotr.com"),
    ContactPerson(id=3, firstname="Aragorn", lastname="Elessar", phone_number="123-333-4444",
                  email="aragorn.elessar@lotr.com"),
    ContactPerson(id=4, firstname="Legolas", lastname="Greenleaf", phone_number="555-666-7777",
                  email="legolas.greenleaf@lotr.com"),
    ContactPerson(id=5, firstname="Gimli", lastname="Son of Gloin", phone_number="888-999-0000",
                  email="gimli.sonofgloin@lotr.com"),
    ContactPerson(id=6, firstname="Gandalf", lastname="The Grey", phone_number="222-333-4444",
                  email="gandalf.thegrey@lotr.com"),
    ContactPerson(id=7, firstname="Boromir", lastname="Son of Denethor", phone_number="111-222-3333",
                  email="boromir.sonofdenethor@lotr.com"),
    ContactPerson(id=8, firstname="Galadriel", lastname="Lady of Lothlórien", phone_number="444-555-6666",
                  email="galadriel.lothlorien@lotr.com"),
    ContactPerson(id=9, firstname="Elrond", lastname="Half-elven", phone_number="777-888-9999",
                  email="elrond.halfelven@lotr.com"),
    ContactPerson(id=10, firstname="Eowyn", lastname="Shieldmaiden of Rohan", phone_number="000-111-2222",
                  email="eowyn.rohan@lotr.com"),
]

return_addresses = [
    Address(id=1, street='123 Hobbiton St', city='Shire', zipcode='12345', country='Middle Earth'),
    Address(id=2, street='456 Rohan Rd', city='Edoras', zipcode='67890', country='Middle Earth'),
    Address(id=3, street='789 Greenwood Dr', city='Mirkwood', zipcode='13579', country='Middle Earth'),
    Address(id=4, street='321 Gondor Ave', city='Minas Tirith', zipcode='24680', country='Middle Earth'),
    Address(id=5, street='654 Falgorn Pass', city='Rivendell', zipcode='11223', country='Middle Earth'),
]

dewars = [
    Dewar(
        id='DEWAR001', dewar_name='Dewar One', tracking_number='TRACK123',
        return_address_id=1, contact_person_id=1, status='Ready for Shipping',
        ready_date=datetime.strptime('2023-09-30', '%Y-%m-%d'), shipping_date=None, arrival_date=None,
        returning_date=None, qrcode='QR123DEWAR001',
    ),
    Dewar(
        id='DEWAR002', dewar_name='Dewar Two', tracking_number='TRACK124',
        return_address_id=2, contact_person_id=2, status='In Preparation',
        ready_date=None, shipping_date=None, arrival_date=None, returning_date=None, qrcode='QR123DEWAR002',
    ),
    Dewar(
        id='DEWAR003', dewar_name='Dewar Three', tracking_number='TRACK125',
        return_address_id=1, contact_person_id=3, status='Not Shipped',
        ready_date=datetime.strptime('2024-01-01', '%Y-%m-%d'), shipping_date=None, arrival_date=None,
        returning_date=None, qrcode='QR123DEWAR003',
    ),
    Dewar(
        id='DEWAR004', dewar_name='Dewar Four', tracking_number='',
        return_address_id=1, contact_person_id=3, status='Delayed',
        ready_date=datetime.strptime('2024-01-01', '%Y-%m-%d'),
        shipping_date=datetime.strptime('2024-01-02', '%Y-%m-%d'),
        arrival_date=None, returning_date=None, qrcode='QR123DEWAR004',
    ),
    Dewar(
        id='DEWAR005', dewar_name='Dewar Five', tracking_number='',
        return_address_id=1, contact_person_id=3, status='Returned',
        arrival_date=datetime.strptime('2024-01-03', '%Y-%m-%d'),
        returning_date=datetime.strptime('2024-01-07', '%Y-%m-%d'),
        qrcode='QR123DEWAR005',
    ),
]

proposals = [
    Proposal(id=1, number="PROPOSAL-FRODO-001"),
    Proposal(id=2, number="PROPOSAL-GANDALF-002"),
    Proposal(id=3, number="PROPOSAL-ARAGORN-003"),
    Proposal(id=4, number="PROPOSAL-SAURON-004"),
    Proposal(id=5, number="PROPOSAL-MORDOR-005"),
]

specific_dewar_ids1 = ['DEWAR003']
specific_dewar_ids2 = ['DEWAR001', 'DEWAR002']
specific_dewar_ids3 = ['DEWAR003', 'DEWAR004', 'DEWAR005']

specific_dewars1 = [dewar for dewar in dewars if dewar.id in specific_dewar_ids1]
specific_dewars2 = [dewar for dewar in dewars if dewar.id in specific_dewar_ids2]
specific_dewars3 = [dewar for dewar in dewars if dewar.id in specific_dewar_ids3]

shipments = [
    Shipment(
        shipment_id="SHIPMENT001", shipment_date=datetime.strptime('2024-10-10', '%Y-%m-%d'),
        shipment_name='Shipment from Mordor', shipment_status='Delivered', contact_person_id=2,
        proposal_id=3, return_address_id=1, comments='Handle with care', dewars=specific_dewars1
    ),
    Shipment(
        shipment_id="SHIPMENT002", shipment_date=datetime.strptime('2024-10-24', '%Y-%m-%d'),
        shipment_name='Shipment from Mordor', shipment_status='In Transit', contact_person_id=4,
        proposal_id=4, return_address_id=2, comments='Contains the one ring', dewars=specific_dewars2
    ),
    Shipment(
        shipment_id="SHIPMENT003", shipment_date=datetime.strptime('2024-10-28', '%Y-%m-%d'),
        shipment_name='Shipment from Mordor', shipment_status='In Transit', contact_person_id=5,
        proposal_id=5, return_address_id=1, comments='Contains the one ring', dewars=specific_dewars3
    ),
]

pucks = [
    Puck(id=1, puck_name="PUCK001", puck_type="Unipuck", puck_location_in_dewar=1, positions=[], dewar_id='DEWAR001'),
    Puck(id=2, puck_name="PUCK002", puck_type="Unipuck", puck_location_in_dewar=2, positions=[], dewar_id='DEWAR001'),
    Puck(id=3, puck_name="PUCK003", puck_type="Unipuck", puck_location_in_dewar=3, positions=[], dewar_id='DEWAR001'),
    Puck(id=4, puck_name="PUCK004", puck_type="Unipuck", puck_location_in_dewar=4, positions=[], dewar_id='DEWAR001'),
    Puck(id=5, puck_name="PUCK005", puck_type="Unipuck", puck_location_in_dewar=5, positions=[], dewar_id='DEWAR001'),
    Puck(id=6, puck_name="PUCK006", puck_type="Unipuck", puck_location_in_dewar=6, positions=[], dewar_id='DEWAR001'),
    Puck(id=7, puck_name="PUCK007", puck_type="Unipuck", puck_location_in_dewar=7, positions=[], dewar_id='DEWAR001'),
    Puck(id=8, puck_name="PK001", puck_type="Unipuck", puck_location_in_dewar=1, positions=[], dewar_id='DEWAR002'),
    Puck(id=9, puck_name="PK002", puck_type="Unipuck", puck_location_in_dewar=2, positions=[], dewar_id='DEWAR002'),
    Puck(id=10, puck_name="PK003", puck_type="Unipuck", puck_location_in_dewar=3, positions=[], dewar_id='DEWAR002'),
    Puck(id=11, puck_name="PK004", puck_type="Unipuck", puck_location_in_dewar=4, positions=[], dewar_id='DEWAR002'),
    Puck(id=12, puck_name="PK005", puck_type="Unipuck", puck_location_in_dewar=5, positions=[], dewar_id='DEWAR002'),
    Puck(id=13, puck_name="PK006", puck_type="Unipuck", puck_location_in_dewar=6, positions=[], dewar_id='DEWAR002'),
    Puck(id=14, puck_name="P001", puck_type="Unipuck", puck_location_in_dewar=1, positions=[], dewar_id='DEWAR003'),
    Puck(id=15, puck_name="P002", puck_type="Unipuck", puck_location_in_dewar=2, positions=[], dewar_id='DEWAR003'),
    Puck(id=16, puck_name="P003", puck_type="Unipuck", puck_location_in_dewar=3, positions=[], dewar_id='DEWAR003'),
    Puck(id=17, puck_name="P004", puck_type="Unipuck", puck_location_in_dewar=4, positions=[], dewar_id='DEWAR003'),
    Puck(id=18, puck_name="P005", puck_type="Unipuck", puck_location_in_dewar=5, positions=[], dewar_id='DEWAR003'),
    Puck(id=19, puck_name="P006", puck_type="Unipuck", puck_location_in_dewar=6, positions=[], dewar_id='DEWAR003'),
    Puck(id=20, puck_name="P007", puck_type="Unipuck", puck_location_in_dewar=7, positions=[], dewar_id='DEWAR003'),
    Puck(id=21, puck_name="PC002", puck_type="Unipuck", puck_location_in_dewar=2, positions=[], dewar_id='DEWAR004'),
    Puck(id=22, puck_name="PC003", puck_type="Unipuck", puck_location_in_dewar=3, positions=[], dewar_id='DEWAR004'),
    Puck(id=23, puck_name="PC004", puck_type="Unipuck", puck_location_in_dewar=4, positions=[], dewar_id='DEWAR004'),
    Puck(id=24, puck_name="PC005", puck_type="Unipuck", puck_location_in_dewar=5, positions=[], dewar_id='DEWAR004'),
    Puck(id=25, puck_name="PC006", puck_type="Unipuck", puck_location_in_dewar=6, positions=[], dewar_id='DEWAR004'),
    Puck(id=26, puck_name="PC007", puck_type="Unipuck", puck_location_in_dewar=7, positions=[], dewar_id='DEWAR004'),
    Puck(id=27, puck_name="PKK004", puck_type="Unipuck", puck_location_in_dewar=4, positions=[], dewar_id='DEWAR005'),
    Puck(id=28, puck_name="PKK005", puck_type="Unipuck", puck_location_in_dewar=5, positions=[], dewar_id='DEWAR005'),
    Puck(id=29, puck_name="PKK006", puck_type="Unipuck", puck_location_in_dewar=6, positions=[], dewar_id='DEWAR005'),
    Puck(id=30, puck_name="PKK007", puck_type="Unipuck", puck_location_in_dewar=7, positions=[], dewar_id='DEWAR005')
]

samples = []
sample_id_counter = 1

for puck in pucks:
    positions_with_samples = random.randint(1, 16)
    occupied_positions = random.sample(range(1, 17), positions_with_samples)

    for pos in range(1, 17):
        if pos in occupied_positions:
            sample = Sample(id=sample_id_counter, sample_name=f"Sample{sample_id_counter:03}", puck_id=puck.id)
            puck.positions.append(sample)
            samples.append(sample)
            sample_id_counter += 1
